@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef THEMEDEFAULTTEMPLATE_H
-#define THEMEDEFAULTTEMPLATE_H
+#pragma once
 
 #include <PimCommon/TemplateListWidget>
 
@@ -14,4 +13,3 @@ namespace ThemeDefaultTemplate
 Q_REQUIRED_RESULT QVector<PimCommon::defaultTemplate> defaultTemplates();
 }
 
-#endif // THEMEDEFAULTTEMPLATE_H
