@@ -1,30 +1,28 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "contacteditormainwindow.h"
-#include "contacteditorpage.h"
-#include "newthemedialog.h"
-#include "managethemes.h"
 #include "contactconfigurationdialog.h"
+#include "contacteditorpage.h"
+#include "managethemes.h"
+#include "newthemedialog.h"
 
-#include <KStandardAction>
-#include <QApplication>
-#include <QAction>
 #include <KActionCollection>
+#include <KAuthorized>
+#include <KConfigGroup>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <QFileDialog>
 #include <KRecentFilesAction>
-#include <KConfigGroup>
-#include <KAuthorized>
+#include <KStandardAction>
+#include <QAction>
+#include <QApplication>
+#include <QFileDialog>
 
-#include <kns3/knewstuffaction.h>
-
-#include <QPointer>
-#include <QCloseEvent>
 #include <KSharedConfig>
+#include <QCloseEvent>
+#include <QPointer>
 #include <QStandardPaths>
 
 ContactEditorMainWindow::ContactEditorMainWindow()
@@ -88,7 +86,9 @@ void ContactEditorMainWindow::setupActions()
     actionCollection()->addAction(QStringLiteral("add_extra_page"), mAddExtraPage);
 
     if (KAuthorized::authorize(QStringLiteral("ghns"))) {
-        mUploadTheme = KNS3::standardAction(i18n("Upload theme..."), this, SLOT(slotUploadTheme()), actionCollection(), "upload_theme");
+        mUploadTheme = new QAction(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")), i18n("Upload theme..."), this);
+        connect(mUploadTheme, &QAction::triggered, this, &ContactEditorMainWindow::slotUploadTheme);
+        actionCollection()->addAction(QStringLiteral("upload_theme"), mUploadTheme);
     }
 
     mNewThemeAction = KStandardAction::openNew(this, &ContactEditorMainWindow::slotNewTheme, actionCollection());
@@ -148,7 +148,7 @@ void ContactEditorMainWindow::slotInsertFile()
 
 void ContactEditorMainWindow::slotInstallTheme()
 {
-    //Save before installing :)
+    // Save before installing :)
     if (slotSaveTheme()) {
         const QString localThemePath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/kaddressbook/viewertemplates/");
         QDir().mkpath(localThemePath);
@@ -158,7 +158,7 @@ void ContactEditorMainWindow::slotInstallTheme()
 
 void ContactEditorMainWindow::slotUploadTheme()
 {
-    //Save before upload :)
+    // Save before upload :)
     if (slotSaveTheme()) {
         mContactEditor->uploadTheme();
     }
@@ -243,8 +243,7 @@ bool ContactEditorMainWindow::saveCurrentProject(ActionSaveTheme act)
     case SaveAndCloseTheme:
         closeThemeEditor();
         break;
-    case SaveAndCreateNewTheme:
-    {
+    case SaveAndCreateNewTheme: {
         delete mContactEditor;
         mContactEditor = nullptr;
         QPointer<GrantleeThemeEditor::NewThemeDialog> dialog = new GrantleeThemeEditor::NewThemeDialog(this);
