@@ -3,8 +3,7 @@
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
-#ifndef CONTACTEDITORUTIL_H
-#define CONTACTEDITORUTIL_H
+#pragma once
 
 #include <QString>
 
@@ -15,4 +14,3 @@ public:
     Q_REQUIRED_RESULT QString defaultContact() const;
 };
 
-#endif
