@@ -3,8 +3,7 @@
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
-#ifndef EDITORPAGE_H
-#define EDITORPAGE_H
+#pragma once
 
 #include "grantleethemeeditor/editorpage.h"
 
@@ -22,7 +21,7 @@ class EditorPage : public GrantleeThemeEditor::EditorPage
     Q_OBJECT
 public:
     explicit EditorPage(GrantleeThemeEditor::EditorPage::PageType type, const QString &projectDirectory, QWidget *parent = nullptr);
-    ~EditorPage();
+    ~EditorPage() override;
 
     GrantleeThemeEditor::PreviewWidget *preview() const;
 
@@ -32,4 +31,3 @@ private:
     QSplitter *mWidgetSplitter = nullptr;
 };
 
-#endif // EDITORPAGE_H
