@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -39,13 +39,13 @@ void PreviewWidget::loadConfig()
 
 void PreviewWidget::createScreenShot(const QStringList &lstFileName)
 {
-    Q_UNUSED(lstFileName);
+    Q_UNUSED(lstFileName)
 }
 
 void PreviewWidget::setThemePath(const QString &projectDirectory, const QString &mainPageFileName)
 {
-    Q_UNUSED(projectDirectory);
-    Q_UNUSED(mainPageFileName);
+    Q_UNUSED(projectDirectory)
+    Q_UNUSED(mainPageFileName)
 }
 
 void PreviewWidget::slotMainFileNameChanged(const QString &)
@@ -54,5 +54,5 @@ void PreviewWidget::slotMainFileNameChanged(const QString &)
 
 void PreviewWidget::slotExtraHeaderDisplayChanged(const QStringList &headers)
 {
-    Q_UNUSED(headers);
+    Q_UNUSED(headers)
 }
