@@ -14,7 +14,7 @@ class GRANTLEETHEMEEDITOR_EXPORT PreviewWidget : public QWidget
     Q_OBJECT
 public:
     explicit PreviewWidget(QWidget *parent = nullptr);
-    ~PreviewWidget();
+    ~PreviewWidget() override;
 
     virtual void updateViewer();
 
