@@ -1,16 +1,15 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
-#ifndef DEFAULTCOMPLETION_H
-#define DEFAULTCOMPLETION_H
+#pragma once
 
 #include <QStringList>
 
-namespace DefaultCompletion {
+namespace DefaultCompletion
+{
 Q_REQUIRED_RESULT QStringList defaultCompetion();
 Q_REQUIRED_RESULT QStringList defaultOptions();
 }
 
-#endif // DEFAULTCOMPLETION_H
