@@ -21,7 +21,7 @@ class EditorPage : public GrantleeThemeEditor::EditorPage
     Q_OBJECT
 public:
     explicit EditorPage(GrantleeThemeEditor::EditorPage::PageType type, const QString &projectDirectory, QWidget *parent = nullptr);
-    ~EditorPage();
+    ~EditorPage() override;
 
     GrantleeThemeEditor::PreviewWidget *preview() const;
 
